@@ -41,9 +41,7 @@ RecordDialog::RecordDialog(QWidget *parent) :
     ui->fileEdit->setText(tr("Select File"));
 
     recording = false;
-    ui->recordPushButton->setEnabled(false);;
-
-    ui->vuMeter->setValue(0);
+    ui->recordPushButton->setEnabled(false);
 
 #ifdef WIN32
     backend = new PortAudioRecordBackend();
@@ -61,7 +59,7 @@ RecordDialog::RecordDialog(QWidget *parent) :
     backend = new PulseAudioRecordBackend();
 #endif
 
-    connect(backend, SIGNAL(updateVuMeterSignal(int)), ui->vuMeter, SLOT(setValue(int)), Qt::QueuedConnection);
+    connect(backend, SIGNAL(updateVuMeterSignal(float)), this, SLOT(setVuMeter(float)), Qt::QueuedConnection);
 }
 
 RecordDialog::~RecordDialog()
@@ -121,3 +119,10 @@ void RecordDialog::recordPushed(){
     }
 }
 
+void RecordDialog::setVuMeter(float volume){
+    if(volume < 0){
+        return;
+    }
+
+    ui->vuMeter->setValue(volume * 100);
+}
